import React, { PureComponent } from 'react';
import { Card, Form, Select, Input, Button, Switch } from 'antd';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import { boolToStatus, statusToBool } from '../../../utils/utils';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};
const submitFormLayout = {
  wrapperCol: {
    xs: { span: 24, offset: 0 },
    sm: { span: 12, offset: 6 },
  },
};

@Form.create()
@connect(({ loading }) => ({
  submitting: loading.models.resource,
}))
export default class VideoEditPage extends PureComponent {
  handlePageBack = () => {
    const { UIParams, Queryers } = this.props.location.state || {};
    this.props.dispatch(
      routerRedux.push({
        pathname: '/resource/video',
        state: { UIParams, Queryers },
      })
    );
  };
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { id, type, UIParams, Queryers } = this.props.location.state || {};
        const { fileList, status, ...params } = values;
        if (Array.isArray(fileList) && fileList.length) {
          params.url = fileList[0].url;
        }
        params.id = id;
        params.type = type;
        params.status = boolToStatus(status);
        this.props.dispatch({
          type: 'resource/updateVideo',
          payload: params,
          states: { UIParams, Queryers },
        });
      }
    });
  };
  render() {
    const { form, submitting, location } = this.props;
    const { getFieldDecorator } = form;
    const { state = {} } = location;
    const { code, name, size, type, path, rate, quality, status } = state;

    return (
      <PageHeaderLayout>
        <Card>
          <Form onSubmit={this.handlePageSubmit}>
            <Form.Item label="视频编号" {...formItemLayout}>
              {getFieldDecorator('code', {
                rules: [{ required: true, message: '视频编号不能为空' }],
                initialValue: code,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="视频名称" {...formItemLayout}>
              {getFieldDecorator('name', {
                rules: [{ required: true, message: '视频名称不能为空' }],
                initialValue: name,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="资源类型" {...formItemLayout}>
              {getFieldDecorator('type', {
                rules: [{ required: true, message: '资源类型不能为空' }],
                initialValue: type,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="资源路径" {...formItemLayout}>
              {getFieldDecorator('path', {
                initialValue: path,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="清晰度" {...formItemLayout}>
              {getFieldDecorator('quality', {
                initialValue: quality,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="资源码流" {...formItemLayout}>
              {getFieldDecorator('rate', {
                initialValue: rate,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="资源大小" {...formItemLayout}>
              {getFieldDecorator('size', {
                initialValue: size,
              })(
                <Input />
              )}
            </Form.Item>
            <Form.Item label="资源状态" {...formItemLayout}>
              {getFieldDecorator('status', {
                valuePropName: 'checked',
                initialValue: statusToBool(status),
              })(
                <Switch
                  checkedChildren="正常"
                  unCheckedChildren="删除"
                />
              )}
            </Form.Item>
            <Form.Item {...submitFormLayout} style={{ marginTop: 32 }}>
              <Button onClick={this.handlePageBack}>取消</Button>
              <Button
                type="primary"
                htmlType="submit"
                loading={submitting}
                style={{ marginLeft: 8 }}
              >提交
              </Button>
            </Form.Item>
          </Form>
        </Card>
      </PageHeaderLayout>
    );
  }
}
