/* eslint-disable no-prototype-builtins */
import React, { Component } from 'react';
import { connect } from 'dva';
import { Card, Button, message } from 'antd';
import VideoPlayList from './VideoPlayList';
import VideoTableList from './VideoTableList';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import { addRowKey } from '../../../utils/utils';

const Message = message;

function deleteBlankKey(obj) {
  if (!(typeof obj === 'object')) {
    return;
  }
  const newObj = { ...obj };
  for (const key in newObj) {
    if (newObj.hasOwnProperty(key) && !newObj[key]) {
      delete newObj[key];
    }
  }
  return newObj;
}

@connect(({ loading, resource }) => ({
  resource,
  loading: loading.models.resource,
}))
export default class VideoListPage extends Component {
  constructor(props) {
    super(props);
    this.state = {
      isCard: false,
      destroy: true,
      current: {},
    };
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: {},
    });
  }
  handleShowTypeChange = () => {
    this.setState({ isCard: !this.state.isCard });
  };
  handleModalDestroy = () => {
    this.setState({ destroy: true });
  };
  handleModalCreate = (item) => {
    this.setState({ destroy: false, current: item });
  };
  // 创建视频(增)
  handleCreateOperation = () => {
  };
  // 删除视频(删)
  handleDeleteOperation = () => {
  };
  // 修改视频(改)
  handleUpdateOperation = () => {
  };
  // 查询视频(查)
  handleFilterOperation = (params) => {
    const newParams = deleteBlankKey(params);
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: newParams,
    });
  };
  // TODO: 批量操作
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  };

  render() {
    const { loading, resource } = this.props;
    const { list, totalSize, pageSize, pageNo } = resource;
    const publicProps = {
      loading,
      pageNo,
      pageSize,
      totalSize,
      dataSource: addRowKey(list),
      onCreateClick: this.handleCreateOperation,
      onDeleteClick: this.handleDeleteOperation,
      onUpdateClick: this.handleUpdateOperation,
      onFilterClick: this.handleFilterOperation,
    };
    return (
      <PageHeaderLayout>
        <Card bordered={false}>
          <Button.Group style={{ marginBottom: 16 }}>
            <Button
              style={{ width: 50 }}
              onClick={this.handleShowTypeChange}
              icon="appstore-o"
              type={this.state.isCard ? 'primary' : null}
            />
            <Button
              style={{ width: 50 }}
              onClick={this.handleShowTypeChange}
              icon="table"
              type={this.state.isCard ? null : 'primary'}
            />
          </Button.Group>
          {this.state.isCard ?
            <VideoPlayList {...publicProps} /> : (
              <VideoTableList
                {...publicProps}
                currentItem={this.state.current}
                modalDestroy={this.state.destroy}
                onModalDestroy={this.handleModalDestroy}
                onModalCreate={this.handleModalCreate}
                onBatchClick={this.handleBatchOperation}
              />
            )
          }
        </Card>
      </PageHeaderLayout>
    );
  }
}
